import { withDirectives as _withDirectives, resolveDirective as _resolveDirective, createVNode as _createVNode } from "vue";
// Styles
import "./VBtn.sass"; // Components

import { VIcon } from "./../index.mjs"; // Composables

import { makeDensityProps, useDensity } from "../../composables/density.mjs";
import { makeBorderProps, useBorder } from "../../composables/border.mjs";
import { makeRoundedProps, useRounded } from "../../composables/rounded.mjs";
import { makeDimensionProps, useDimension } from "../../composables/dimensions.mjs";
import { makeElevationProps, useElevation } from "../../composables/elevation.mjs";
import { makePositionProps, usePosition } from "../../composables/position.mjs";
import { makeTagProps } from "../../composables/tag.mjs";
import { makeThemeProps, useTheme } from "../../composables/theme.mjs";
import { useColor } from "../../composables/color.mjs"; // Directives

import { Ripple } from "../../directives/ripple/index.mjs"; // Utilities

import { computed, defineComponent } from 'vue';
import { makeProps } from "../../util/index.mjs";
import { makeSizeProps, useSize } from "../../composables/size.mjs";
export default defineComponent({
  name: 'VBtn',
  directives: {
    Ripple
  },
  props: makeProps({
    text: Boolean,
    flat: Boolean,
    plain: Boolean,
    icon: [Boolean, String],
    prependIcon: String,
    appendIcon: String,
    block: Boolean,
    stacked: Boolean,
    color: String,
    disabled: Boolean,
    ...makeBorderProps(),
    ...makeRoundedProps(),
    ...makeDensityProps(),
    ...makeDimensionProps(),
    ...makeElevationProps(),
    ...makePositionProps(),
    ...makeSizeProps(),
    ...makeTagProps({
      tag: 'button'
    }),
    ...makeThemeProps()
  }),

  setup(props, {
    slots
  }) {
    const {
      themeClasses
    } = useTheme(props);
    const {
      borderClasses
    } = useBorder(props, 'v-btn');
    const {
      roundedClasses
    } = useRounded(props, 'v-btn');
    const {
      densityClasses
    } = useDensity(props, 'v-btn');
    const {
      dimensionStyles
    } = useDimension(props);
    const {
      elevationClasses
    } = useElevation(props);
    const {
      positionClasses,
      positionStyles
    } = usePosition(props, 'v-btn');
    const {
      sizeClasses
    } = useSize(props, 'v-btn');
    const isContained = computed(() => {
      return !(props.text || props.plain || props.outlined || props.border !== false);
    });
    const isElevated = computed(() => {
      return isContained.value && !(props.disabled || props.flat);
    });
    const {
      colorClasses,
      colorStyles
    } = useColor(computed(() => ({
      [isContained.value ? 'background' : 'text']: props.color
    })));
    return () => {
      var _slots$default;

      return _withDirectives(_createVNode(props.tag, {
        "type": "button",
        "class": ['v-btn', {
          'v-btn--contained': isContained.value,
          'v-btn--elevated': isElevated.value,
          'v-btn--icon': !!props.icon,
          'v-btn--plain': props.plain,
          'v-btn--block': props.block,
          'v-btn--disabled': props.disabled,
          'v-btn--stacked': props.stacked
        }, themeClasses.value, borderClasses.value, colorClasses.value, densityClasses.value, elevationClasses.value, positionClasses.value, roundedClasses.value, sizeClasses.value],
        "style": [colorStyles.value, dimensionStyles.value, positionStyles.value],
        "disabled": props.disabled
      }, {
        default: () => [_createVNode("span", {
          "class": "v-btn__overlay"
        }, null), !props.icon && props.prependIcon && _createVNode(VIcon, {
          "class": "v-btn__icon",
          "icon": props.prependIcon,
          "left": !props.stacked
        }, null, 8, ["icon", "left"]), typeof props.icon === 'boolean' ? (_slots$default = slots.default) == null ? void 0 : _slots$default.call(slots) : _createVNode(VIcon, {
          "class": "v-btn__icon",
          "icon": props.icon,
          "size": props.size
        }, null, 8, ["icon", "size"]), !props.icon && props.appendIcon && _createVNode(VIcon, {
          "class": "v-btn__icon",
          "icon": props.appendIcon,
          "right": !props.stacked
        }, null, 8, ["icon", "right"])],
        _: 1
      }, 8, ["class", "style", "disabled"]), [[_resolveDirective("ripple"), !props.disabled, null]]);
    };
  }

});
//# sourceMappingURL=VBtn.mjs.map