import { withDirectives as _withDirectives, resolveDirective as _resolveDirective, createVNode as _createVNode } from "vue";
// Styles
import "./VCard.sass"; // Components

import { VCardActions, VCardAvatar, VCardHeader, VCardHeaderText, VCardImg, VCardMedia, VCardSubtitle, VCardText, VCardTitle } from "./index.mjs";
import { VAvatar } from "../VAvatar/index.mjs";
import { VImg } from "../VImg/index.mjs"; // Composables

import { makeBorderProps, useBorder } from "../../composables/border.mjs";
import { makeDensityProps, useDensity } from "../../composables/density.mjs";
import { makeDimensionProps, useDimension } from "../../composables/dimensions.mjs";
import { makeElevationProps, useElevation } from "../../composables/elevation.mjs";
import { makePositionProps, usePosition } from "../../composables/position.mjs";
import { makeRoundedProps, useRounded } from "../../composables/rounded.mjs";
import { makeTagProps } from "../../composables/tag.mjs";
import { useBackgroundColor } from "../../composables/color.mjs";
import { makeThemeProps, useTheme } from "../../composables/theme.mjs"; // Directives

import { Ripple } from "../../directives/ripple/index.mjs"; // Utilities

import { defineComponent, toRef } from 'vue';
import { makeProps } from "../../util/index.mjs";
export default defineComponent({
  name: 'VCard',
  directives: {
    Ripple
  },
  props: makeProps({
    appendAvatar: String,
    appendIcon: String,
    color: String,
    disabled: Boolean,
    flat: Boolean,
    hover: Boolean,
    image: String,
    link: Boolean,
    prependAvatar: String,
    prependIcon: String,
    ripple: Boolean,
    subtitle: String,
    text: String,
    title: String,
    ...makeThemeProps(),
    ...makeBorderProps(),
    ...makeDensityProps(),
    ...makeDimensionProps(),
    ...makeElevationProps(),
    ...makePositionProps(),
    ...makeRoundedProps(),
    ...makeTagProps()
  }),

  setup(props, {
    slots
  }) {
    const {
      themeClasses
    } = useTheme(props);
    const {
      backgroundColorClasses,
      backgroundColorStyles
    } = useBackgroundColor(toRef(props, 'color'));
    const {
      borderClasses
    } = useBorder(props, 'v-card');
    const {
      dimensionStyles
    } = useDimension(props);
    const {
      elevationClasses
    } = useElevation(props);
    const {
      positionClasses,
      positionStyles
    } = usePosition(props, 'v-card');
    const {
      roundedClasses
    } = useRounded(props, 'v-card');
    const {
      densityClasses
    } = useDensity(props, 'v-card');
    return () => {
      var _slots$image, _slots$default;

      const hasTitle = !!(slots.title || props.title);
      const hasSubtitle = !!(slots.subtitle || props.subtitle);
      const hasHeaderText = !!(hasTitle || hasSubtitle);
      const hasAppend = !!(slots.append || props.appendAvatar || props.appendIcon);
      const hasPrepend = !!(slots.prepend || props.prependAvatar || props.prependIcon);
      const hasImage = !!(slots.image || props.image);
      const hasHeader = hasHeaderText || hasPrepend || hasAppend;
      const hasText = !!(slots.text || props.text);
      const hasOverlay = props.link && !props.disabled;
      return _withDirectives(_createVNode(props.tag, {
        "class": ['v-card', {
          'v-card--disabled': props.disabled,
          'v-card--flat': props.flat,
          'v-card--hover': props.hover && !(props.disabled || props.flat),
          'v-card--link': props.link
        }, themeClasses.value, backgroundColorClasses.value, borderClasses.value, densityClasses.value, elevationClasses.value, positionClasses.value, roundedClasses.value],
        "style": [backgroundColorStyles.value, dimensionStyles.value, positionStyles.value]
      }, {
        default: () => [hasOverlay && _createVNode("div", {
          "class": "v-card__overlay"
        }, null), hasImage && _createVNode(VCardImg, null, {
          default: () => [slots.image ? (_slots$image = slots.image) == null ? void 0 : _slots$image.call(slots, {
            src: props.image
          }) : _createVNode(VImg, {
            "src": props.image,
            "alt": ""
          }, null, 8, ["src"])]
        }), slots.media && _createVNode(VCardMedia, null, {
          default: slots.media
        }), hasHeader && _createVNode(VCardHeader, null, {
          default: () => [hasPrepend && _createVNode(VCardAvatar, null, {
            default: () => [slots.prepend ? slots.prepend() : _createVNode(VAvatar, {
              "density": props.density,
              "icon": props.prependIcon,
              "image": props.prependAvatar
            }, null, 8, ["density", "icon", "image"])]
          }), hasHeaderText && _createVNode(VCardHeaderText, null, {
            default: () => [hasTitle && _createVNode(VCardTitle, null, {
              default: () => [slots.title ? slots.title() : props.title]
            }), _createVNode(VCardSubtitle, null, {
              default: () => [slots.subtitle ? slots.subtitle() : props.subtitle]
            })],
            _: 1
          }), hasAppend && _createVNode(VCardAvatar, null, {
            default: () => [slots.append ? slots.append() : _createVNode(VAvatar, {
              "density": props.density,
              "icon": props.appendIcon,
              "image": props.appendAvatar
            }, null, 8, ["density", "icon", "image"])]
          })],
          _: 1
        }), hasText && _createVNode(VCardText, null, {
          default: () => [slots.text ? slots.text() : props.text]
        }), (_slots$default = slots.default) == null ? void 0 : _slots$default.call(slots), slots.actions && _createVNode(VCardActions, null, {
          default: slots.actions
        })],
        _: 1
      }, 8, ["class", "style"]), [[_resolveDirective("ripple"), hasOverlay]]);
    };
  }

});
//# sourceMappingURL=VCard.mjs.map