import { createVNode as _createVNode, mergeProps as _mergeProps, resolveDirective as _resolveDirective } from "vue";
// Styles
import "./VDialog.sass"; // Components

import { VDialogTransition } from "../transitions/index.mjs";
import { VOverlay } from "../VOverlay/index.mjs"; // Composables

import { makeDimensionProps, useDimension } from "../../composables/dimensions.mjs";
import { makeTransitionProps } from "../../composables/transition.mjs";
import { useProxiedModel } from "../../composables/proxiedModel.mjs"; // Utilities

import { defineComponent, mergeProps, ref, watch } from 'vue';
import { makeProps } from "../../util/makeProps.mjs"; // Globals

import { IN_BROWSER } from "../../util/index.mjs";
export default defineComponent({
  name: 'VDialog',
  props: makeProps({
    fullscreen: Boolean,
    origin: {
      type: String,
      default: 'center center'
    },
    retainFocus: {
      type: Boolean,
      default: true
    },
    scrollable: Boolean,
    modelValue: Boolean,
    ...makeDimensionProps({
      width: 'auto'
    }),
    ...makeTransitionProps({
      transition: {
        component: VDialogTransition
      }
    })
  }),
  emits: {
    'update:modelValue': value => true
  },

  setup(props, {
    attrs,
    slots
  }) {
    const isActive = useProxiedModel(props, 'modelValue');
    const {
      dimensionStyles
    } = useDimension(props);
    const overlay = ref();

    function onFocusin(e) {
      var _overlay$value;

      const before = e.relatedTarget;
      const after = e.target;

      if (before !== after && (_overlay$value = overlay.value) != null && _overlay$value.content && // It isn't the document or the dialog body
      ![document, overlay.value.content].includes(after) && // It isn't inside the dialog body
      !overlay.value.content.contains(after) // We're the topmost dialog
      // TODO: this.activeZIndex >= this.getMaxZIndex() &&
      // It isn't inside a dependent element (like a menu)
      // TODO: !this.getOpenDependentElements().some(el => el.contains(target))
      // So we must have focused something outside the dialog and its children
      ) {
          const focusable = [...overlay.value.content.querySelectorAll('button, [href], input, select, textarea, [tabindex]:not([tabindex="-1"])')].filter(el => !el.hasAttribute('disabled'));
          if (!focusable.length) return;
          const firstElement = focusable[0];
          const lastElement = focusable[focusable.length - 1];

          if (before === firstElement) {
            lastElement.focus();
          } else {
            firstElement.focus();
          }
        }
    }

    if (IN_BROWSER) {
      watch(() => isActive.value && props.retainFocus, val => {
        val ? document.addEventListener('focusin', onFocusin) : document.removeEventListener('focusin', onFocusin);
      }, {
        immediate: true
      });
    }

    const activatorElement = ref();

    const activator = ({
      props,
      ...data
    }) => {
      var _slots$activator;

      return (_slots$activator = slots.activator) == null ? void 0 : _slots$activator.call(slots, { ...data,
        props: mergeProps(props, {
          'aria-haspopup': 'dialog',
          onClick: e => {
            activatorElement.value = e.currentTarget;
          }
        })
      });
    };

    return () => {
      const transition = mergeProps({
        target: activatorElement.value
      }, typeof props.transition === 'string' ? {
        name: props.transition
      } : props.transition);
      return _createVNode(VOverlay, _mergeProps({
        "modelValue": isActive.value,
        "onUpdate:modelValue": $event => isActive.value = $event,
        "class": ['v-dialog', {
          'v-dialog--fullscreen': props.fullscreen
        }],
        "style": dimensionStyles.value,
        "transition": transition,
        "ref": overlay,
        "aria-role": "dialog",
        "aria-modal": "true"
      }, attrs), {
        default: slots.default,
        activator
      }, 16, ["modelValue", "onUpdate:modelValue", "class", "style", "transition"]);
    };
  }

});
//# sourceMappingURL=VDialog.mjs.map