import { withDirectives as _withDirectives, resolveDirective as _resolveDirective, createVNode as _createVNode } from "vue";
// Styles
import "./VListItem.sass"; // Components

import { VListItemAvatar, VListItemHeader, VListItemSubtitle, VListItemTitle } from "./index.mjs";
import { VAvatar } from "../VAvatar/index.mjs"; // Composables

import { makeBorderProps, useBorder } from "../../composables/border.mjs";
import { makeDensityProps, useDensity } from "../../composables/density.mjs";
import { makeDimensionProps, useDimension } from "../../composables/dimensions.mjs";
import { makeElevationProps, useElevation } from "../../composables/elevation.mjs";
import { makeRoundedProps, useRounded } from "../../composables/rounded.mjs";
import { makeTagProps } from "../../composables/tag.mjs";
import { useColor } from "../../composables/color.mjs";
import { makeThemeProps, useTheme } from "../../composables/theme.mjs"; // Directives

import { Ripple } from "../../directives/ripple/index.mjs"; // Utilities

import { computed, defineComponent } from 'vue';
import { makeProps } from "../../util/index.mjs";
export default defineComponent({
  name: 'VListItem',
  directives: {
    Ripple
  },
  props: makeProps({
    active: Boolean,
    activeColor: String,
    activeClass: String,
    appendAvatar: String,
    appendIcon: String,
    color: String,
    disabled: Boolean,
    link: Boolean,
    prependAvatar: String,
    prependIcon: String,
    subtitle: String,
    contained: String,
    title: String,
    ...makeBorderProps(),
    ...makeDensityProps(),
    ...makeDimensionProps(),
    ...makeElevationProps(),
    ...makeRoundedProps(),
    ...makeTagProps(),
    ...makeThemeProps()
  }),

  setup(props, {
    attrs,
    slots
  }) {
    const {
      themeClasses
    } = useTheme(props);
    const {
      colorClasses,
      colorStyles
    } = useColor(computed(() => {
      const key = props.contained && props.active ? 'background' : 'text';
      const color = props.active && props.activeColor || props.color;
      return {
        [`${key}`]: color
      };
    }));
    const {
      borderClasses
    } = useBorder(props, 'v-list-item');
    const {
      densityClasses
    } = useDensity(props, 'v-list-item');
    const {
      dimensionStyles
    } = useDimension(props);
    const {
      elevationClasses
    } = useElevation(props);
    const {
      roundedClasses
    } = useRounded(props, 'v-list-item');
    return () => {
      var _slots$default;

      const hasTitle = slots.title || props.title;
      const hasSubtitle = slots.subtitle || props.subtitle;
      const hasHeader = !!(hasTitle || hasSubtitle);
      const hasAppend = slots.append || props.appendAvatar || props.appendIcon;
      const hasPrepend = slots.prepend || props.prependAvatar || props.prependIcon;
      const isLink = !!(props.link || attrs.onClick || attrs.onClickOnce);
      const isClickable = isLink && !props.disabled;
      return _withDirectives(_createVNode(props.tag, {
        "class": ['v-list-item', {
          'v-list-item--active': props.active,
          'v-list-item--disabled': props.disabled,
          'v-list-item--link': isLink,
          'v-list-item--contained': props.contained,
          [`${props.activeClass}`]: props.active && props.activeClass
        }, themeClasses.value, colorClasses.value, borderClasses.value, densityClasses.value, elevationClasses.value, roundedClasses.value],
        "style": [colorStyles.value, dimensionStyles.value],
        "tabindex": isClickable ? 0 : undefined
      }, {
        default: () => [(isClickable || props.active) && _createVNode("div", {
          "class": "v-list-item__overlay"
        }, null), hasPrepend && (slots.prepend ? slots.prepend() : _createVNode(VListItemAvatar, {
          "left": true
        }, {
          default: () => [_createVNode(VAvatar, {
            "density": props.density,
            "icon": props.prependIcon,
            "image": props.prependAvatar
          }, null, 8, ["density", "icon", "image"])]
        }, 8, ["left"])), hasHeader && _createVNode(VListItemHeader, null, {
          default: () => [hasTitle && _createVNode(VListItemTitle, null, {
            default: () => [slots.title ? slots.title() : props.title]
          }), hasSubtitle && _createVNode(VListItemSubtitle, null, {
            default: () => [slots.subtitle ? slots.subtitle() : props.subtitle]
          })],
          _: 1
        }), (_slots$default = slots.default) == null ? void 0 : _slots$default.call(slots), hasAppend && (slots.append ? slots.append() : _createVNode(VListItemAvatar, {
          "right": true
        }, {
          default: () => [_createVNode(VAvatar, {
            "density": props.density,
            "icon": props.appendIcon,
            "image": props.appendAvatar
          }, null, 8, ["density", "icon", "image"])]
        }, 8, ["right"]))],
        _: 1
      }, 8, ["class", "style", "tabindex"]), [[_resolveDirective("ripple"), isClickable]]);
    };
  }

});
//# sourceMappingURL=VListItem.mjs.map