import { createVNode as _createVNode, createTextVNode as _createTextVNode } from "vue";
/// <reference types="../../../types/cypress" />
import { CenteredGrid } from "../../../cypress/templates/index.mjs";
import { createVuetify } from "../../framework.mjs";
import { VBtn } from "./../index.mjs";
import { VThemeProvider } from "./index.mjs";
describe('VThemeProvider', () => {
  const vuetify = createVuetify();
  it('should use provided theme', () => {
    cy.mount(() => _createVNode(VThemeProvider, null, {
      default: () => [_createVNode(CenteredGrid, {
        "class": "pa-10"
      }, {
        default: () => [_createVNode(VBtn, {
          "color": "primary"
        }, {
          default: () => [_createTextVNode("button")]
        })]
      })]
    }), {
      global: {
        plugins: [vuetify]
      }
    }).get('.v-btn').should('have.class', 'v-theme--light');
  });
  it('should use theme defined in prop', () => {
    cy.mount(() => _createVNode(VThemeProvider, {
      "theme": "dark"
    }, {
      default: () => [_createVNode(CenteredGrid, {
        "class": "pa-10"
      }, {
        default: () => [_createVNode(VBtn, {
          "color": "primary"
        }, {
          default: () => [_createTextVNode("button")]
        })]
      })]
    }), {
      global: {
        plugins: [vuetify]
      }
    }).get('.v-btn').should('have.class', 'v-theme--dark');
  });
  it('should render element when using with-background prop', () => {
    cy.mount(() => _createVNode(VThemeProvider, {
      "theme": "dark",
      "with-background": true
    }, {
      default: () => [_createVNode(CenteredGrid, {
        "class": "pa-10"
      }, {
        default: () => [_createVNode(VBtn, {
          "color": "primary"
        }, {
          default: () => [_createTextVNode("button")]
        })]
      })]
    }, 8, ["with-background"]), {
      global: {
        plugins: [vuetify]
      }
    }).get('.v-theme-provider').should('exist');
  });
});
//# sourceMappingURL=VThemeProvider.cy.spec.mjs.map